QuoteStyle

Enum QuoteStyle 

#[non_exhaustive]
pub enum QuoteStyle { Necessary, Always, NonNumeric, Never, }
When fields are quoted.

use deser_csv::{QuoteStyle, SerializerConfig};

let rows = vec![("a b", 1), ("c,d", 2)];
let with = |style| {
    SerializerConfig::new().quote_style(style).to_string(&rows).unwrap()
};
assert_eq!(with(QuoteStyle::Necessary), "a b,1\n\"c,d\",2\n");
assert_eq!(with(QuoteStyle::Always), "\"a b\",\"1\"\n\"c,d\",\"2\"\n");
assert_eq!(with(QuoteStyle::NonNumeric), "\"a b\",1\n\"c,d\",2\n");

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Necessary

Fields are quoted if they have to be (if they contain special characters or would otherwise be read differently).



Always

All fields are quoted.



NonNumeric

All fields except for numbers are quoted.



Never

Fields are never quoted, fields that need quotes are an error (unless they can be escaped, see Escape).